HtmlElement

Struct HtmlElement 

pub struct HtmlElement<C> { /* private fields */ }
A Generic html node with a given name.

Implementations

Source

impl<C> HtmlElement<C>

pub fn new(tag: &'static str) -> Self

Create a new html element with the specific tag

All non-deprecated html elements have a helper function in this module

pub fn on<E: Event>(self, function: impl EventHandler<C, E::JsEvent>) -> Self

Register a event handler for this element.

The event handler is a closure taking a mutable reference to S<Self>.

e::button().on("click", |ctx: &mut S<Self>| {
    *ctx.some_value += 1;
})

For more information see Reactivity in the book.

pub fn child<E: Element<C> + 'static>(self, child: E) -> Self

Push a child to this element. This accepts any valid element including closures.

e::div()
    .child(e::h1().text("Wow!"))
    .child(|ctx: &S<Self>| {
        if *ctx.toggle {
            "Hello"
        } else {
            "World"
        }
    })
pub fn text<E: Element<C>>(self, text: E) -> Self

This is a simple alias for child

pub fn attr(self, key: &'static str, value: impl ToAttribute<C>) -> Self

Add a attribute to the node.

See Html Nodes in the book for the schematics of the various valid attribute types.

pub fn id(self, id: &'static str) -> Self

Shorthand for .attr("id", ...) with a specific ID.

pub fn class(self, class: &'static str) -> Self

Add a class to the element.